==> snd-12.11.tar.gz: snd-12.11/sndlib-strings.h <==
#ifndef SNDLIB_STRINGS_H
#define SNDLIB_STRINGS_H

#define S_array_to_file                 "array->file"
#define S_file_to_array                 "file->array"
#define S_make_sound_data               "make-sound-data"
#define S_mus_aifc                      "mus-aifc"
#define S_mus_aiff                      "mus-aiff"
#define S_mus_alaw                      "mus-alaw"
#define S_mus_alsa_buffer_size          "mus-alsa-buffer-size"
#define S_mus_alsa_buffers              "mus-alsa-buffers"
#define S_mus_alsa_capture_device       "mus-alsa-capture-device"
#define S_mus_alsa_device               "mus-alsa-device"
#define S_mus_alsa_playback_device      "mus-alsa-playback-device"
#define S_mus_alsa_squelch_warning      "mus-alsa-squelch-warning"
#define S_mus_audio_close               "mus-audio-close"
#define S_mus_audio_default             "mus-audio-default"
#define S_mus_audio_open_input          "mus-audio-open-input"
#define S_mus_audio_open_output         "mus-audio-open-output"
#define S_mus_audio_read                "mus-audio-read"
#define S_mus_audio_write               "mus-audio-write"
#define S_mus_b24int                    "mus-b24int"
#define S_mus_bdouble                   "mus-bdouble"
#define S_mus_bdouble_unscaled          "mus-bdouble-unscaled"
#define S_mus_bfloat                    "mus-bfloat"
#define S_mus_bfloat_unscaled           "mus-bfloat-unscaled"
#define S_mus_bicsf                     "mus-bicsf"
#define S_mus_bint                      "mus-bint"
#define S_mus_bintn                     "mus-bintn"
#define S_mus_bshort                    "mus-bshort"
#define S_mus_byte                      "mus-byte"
#define S_mus_bytes_per_sample          "mus-bytes-per-sample"
#define S_mus_caff                      "mus-caff"
#define S_mus_clipping                  "mus-clipping"
#define S_mus_data_format_name          "mus-data-format-name"
#define S_mus_data_format_to_string     "mus-data-format->string"
#define S_mus_error_type_to_string      "mus-error-type->string"
#define S_mus_expand_filename           "mus-expand-filename"
#define S_mus_file_clipping             "mus-file-clipping"
#define S_mus_file_prescaler            "mus-file-prescaler"
#define S_mus_header_raw_defaults       "mus-header-raw-defaults"
#define S_mus_header_type_name          "mus-header-type-name"
#define S_mus_header_type_to_string     "mus-header-type->string"
#define S_mus_ircam                     "mus-ircam"
#define S_mus_l24int                    "mus-l24int"
#define S_mus_ldouble                   "mus-ldouble"
#define S_mus_ldouble_unscaled          "mus-ldouble-unscaled"
#define S_mus_lfloat                    "mus-lfloat"
#define S_mus_lfloat_unscaled           "mus-lfloat-unscaled"
#define S_mus_lint                      "mus-lint"
#define S_mus_lintn                     "mus-lintn"
#define S_mus_lshort                    "mus-lshort"
#define S_mus_max_malloc                "mus-max-malloc"
#define S_mus_max_table_size            "mus-max-table-size"
#define S_mus_mulaw                     "mus-mulaw"
#define S_mus_next                      "mus-next"
#define S_mus_nist                      "mus-nist"
#define S_mus_oss_set_buffers           "mus-oss-set-buffers"
#define S_mus_out_format                "mus-out-format"
#define S_mus_prescaler                 "mus-prescaler"
#define S_mus_raw                       "mus-raw"
#define S_mus_rf64                      "mus-rf64"
#define S_mus_riff                      "mus-riff"
#define S_mus_sound_chans               "mus-sound-chans"
#define S_mus_sound_close_input         "mus-sound-close-input"
#define S_mus_sound_close_output        "mus-sound-close-output"
#define S_mus_sound_comment             "mus-sound-comment"
#define S_mus_sound_data_format         "mus-sound-data-format"
#define S_mus_sound_data_location       "mus-sound-data-location"
#define S_mus_sound_datum_size          "mus-sound-datum-size"
#define S_mus_sound_duration            "mus-sound-duration"
#define S_mus_sound_forget              "mus-sound-forget"
#define S_mus_sound_frames              "mus-sound-frames"
#define S_mus_sound_header_type         "mus-sound-header-type"
#define S_mus_sound_length              "mus-sound-length"
#define S_mus_sound_loop_info           "mus-sound-loop-info"
#define S_mus_sound_mark_info           "mus-sound-mark-info"
#define S_mus_sound_maxamp              "mus-sound-maxamp"
#define S_mus_sound_maxamp_exists       "mus-sound-maxamp-exists?"
#define S_mus_sound_open_input          "mus-sound-open-input"
#define S_mus_sound_open_output         "mus-sound-open-output"
#define S_mus_sound_prune               "mus-sound-prune"
#define S_mus_sound_read                "mus-sound-read"
#define S_mus_sound_reopen_output       "mus-sound-reopen-output"
#define S_mus_sound_report_cache        "mus-sound-report-cache"
#define S_mus_sound_samples             "mus-sound-samples"
#define S_mus_sound_seek_frame          "mus-sound-seek-frame"
#define S_mus_sound_srate               "mus-sound-srate"
#define S_mus_sound_type_specifier      "mus-sound-type-specifier"
#define S_mus_sound_write               "mus-sound-write"
#define S_mus_sound_write_date          "mus-sound-write-date"
#define S_mus_soundfont                 "mus-soundfont"
#define S_mus_svx                       "mus-svx"
#define S_mus_ubshort                   "mus-ubshort"
#define S_mus_ubyte                     "mus-ubyte"
#define S_mus_ulshort                   "mus-ulshort"
#define S_mus_unknown                   "mus-unknown"
#define S_mus_unsupported               "mus-unsupported"
#define S_mus_voc                       "mus-voc"
#define S_new_sound_hook                "new-sound-hook"
#define S_sound_data_addB               "sound-data-add!"
#define S_sound_data_chans              "sound-data-chans"
#define S_sound_data_copy               "sound-data-copy"
#define S_sound_data_fillB              "sound-data-fill!"
#define S_sound_data_length             "sound-data-length"
#define S_sound_data_maxamp             "sound-data-maxamp"
#define S_sound_data_multiplyB          "sound-data-multiply!"
#define S_sound_data_offsetB            "sound-data-offset!"
#define S_sound_data_p                  "sound-data?"
#define S_sound_data_peak               "sound-data-peak"
#define S_sound_data_ref                "sound-data-ref"
#define S_sound_data_reverseB           "sound-data-reverse!"
#define S_sound_data_scaleB             "sound-data-scale!"
#define S_sound_data_setB               "sound-data-set!"
#define S_sound_data_to_vct             "sound-data->vct"
#define S_vct_to_sound_data             "vct->sound-data"
#if HAVE_RUBY
  #define S_sound_data_multiply         "sound_data_multiply"
  #define S_sound_data_add              "sound_data_add"
#else
  #define S_sound_data_multiply         "sound-data*"
  #define S_sound_data_add              "sound-data+"
#endif
#endif

==> snd_17.7.orig.tar.gz: snd-17.7/sndlib-strings.h <==
#ifndef SNDLIB_STRINGS_H
#define SNDLIB_STRINGS_H

#define S_array_to_file                 "array->file"
#define S_file_to_array                 "file->array"
#define S_mus_aifc                      "mus-aifc"
#define S_mus_aiff                      "mus-aiff"
#define S_mus_alaw                      "mus-alaw"
#define S_mus_alsa_buffer_size          "mus-alsa-buffer-size"
#define S_mus_alsa_buffers              "mus-alsa-buffers"
#define S_mus_alsa_capture_device       "mus-alsa-capture-device"
#define S_mus_alsa_device               "mus-alsa-device"
#define S_mus_alsa_playback_device      "mus-alsa-playback-device"
#define S_mus_alsa_squelch_warning      "mus-alsa-squelch-warning"
#define S_mus_b24int                    "mus-b24int"
#define S_mus_bdouble                   "mus-bdouble"
#define S_mus_bdouble_unscaled          "mus-bdouble-unscaled"
#define S_mus_bfloat                    "mus-bfloat"
#define S_mus_bfloat_unscaled           "mus-bfloat-unscaled"
#define S_mus_bicsf                     "mus-bicsf"
#define S_mus_bint                      "mus-bint"
#define S_mus_bintn                     "mus-bintn"
#define S_mus_bshort                    "mus-bshort"
#define S_mus_byte                      "mus-byte"
#define S_mus_bytes_per_sample          "mus-bytes-per-sample"
#define S_mus_caff                      "mus-caff"
#define S_mus_clipping                  "mus-clipping"
#define S_mus_sample_type_name          "mus-sample-type-name"
#define S_mus_sample_type_to_string     "mus-sample-type->string"
#define S_mus_error_type_to_string      "mus-error-type->string"
#define S_mus_expand_filename           "mus-expand-filename"
#define S_mus_file_clipping             "mus-file-clipping"
#define S_mus_header_raw_defaults       "mus-header-raw-defaults"
#define S_mus_header_type_name          "mus-header-type-name"
#define S_mus_header_type_to_string     "mus-header-type->string"
#define S_mus_header_writable           "mus-header-writable"
#define S_mus_ircam                     "mus-ircam"
#define S_mus_l24int                    "mus-l24int"
#define S_mus_ldouble                   "mus-ldouble"
#define S_mus_ldouble_unscaled          "mus-ldouble-unscaled"
#define S_mus_lfloat                    "mus-lfloat"
#define S_mus_lfloat_unscaled           "mus-lfloat-unscaled"
#define S_mus_lint                      "mus-lint"
#define S_mus_lintn                     "mus-lintn"
#define S_mus_lshort                    "mus-lshort"
#define S_mus_max_malloc                "mus-max-malloc"
#define S_mus_max_table_size            "mus-max-table-size"
#define S_mus_mulaw                     "mus-mulaw"
#define S_mus_next                      "mus-next"
#define S_mus_nist                      "mus-nist"
#define S_mus_oss_set_buffers           "mus-oss-set-buffers"
#define S_mus_out_format                "mus-out-format"
#define S_mus_raw                       "mus-raw"
#define S_mus_rf64                      "mus-rf64"
#define S_mus_riff                      "mus-riff"
#define S_mus_sound_chans               "mus-sound-chans"
#define S_mus_sound_comment             "mus-sound-comment"
#define S_mus_sound_sample_type         "mus-sound-sample-type"
#define S_mus_sound_data_location       "mus-sound-data-location"
#define S_mus_sound_datum_size          "mus-sound-datum-size"
#define S_mus_sound_duration            "mus-sound-duration"
#define S_mus_sound_forget              "mus-sound-forget"
#define S_mus_sound_framples            "mus-sound-framples"
#define S_mus_sound_header_type         "mus-sound-header-type"
#define S_mus_sound_length              "mus-sound-length"
#define S_mus_sound_loop_info           "mus-sound-loop-info"
#define S_mus_sound_mark_info           "mus-sound-mark-info"
#define S_mus_sound_maxamp              "mus-sound-maxamp"
#define S_mus_sound_maxamp_exists       "mus-sound-maxamp-exists?"
#define S_mus_sound_path                "mus-sound-path"
#define S_mus_sound_prune               "mus-sound-prune"
#define S_mus_sound_report_cache        "mus-sound-report-cache"
#define S_mus_sound_samples             "mus-sound-samples"
#define S_mus_sound_srate               "mus-sound-srate"
#define S_mus_sound_type_specifier      "mus-sound-type-specifier"
#define S_mus_sound_write_date          "mus-sound-write-date"
#define S_mus_soundfont                 "mus-soundfont"
#define S_mus_svx                       "mus-svx"
#define S_mus_ubshort                   "mus-ubshort"
#define S_mus_ubyte                     "mus-ubyte"
#define S_mus_ulshort                   "mus-ulshort"
#define S_mus_unknown_header            "mus-unknown-header"
#define S_mus_unknown_sample            "mus-unknown-sample"
#define S_mus_voc                       "mus-voc"
#define S_new_sound_hook                "new-sound-hook"

#endif
